==> emodpy_covid-0.0.30-py3-none-any.whl: emodpy_covid/microstructure/test_change_ser_pop.py <==
import json
import unittest
import os
import hashlib

# Code under test
import SerializedPopulation as SP
import hh_gen_toy as TOY
import add_hh_to_demo as ADD
import change_ser_pop as CSP

class ChangeSerializedPopulationTest(unittest.TestCase):
    def setUp(self) -> None:
        my_path = os.getcwd()
        self.generic_spop_path = os.path.join(my_path, "TestContent", "state-generic-00050.dtk")
        self.environmental_spop_path = os.path.join(my_path, "TestContent", "state-environmental-00050.dtk")
        if not os.path.isfile(self.generic_spop_path):
            raise FileNotFoundError(f"Need {self.generic_spop_path} in place to run these tests")
        if not os.path.isfile(self.environmental_spop_path):
            raise FileNotFoundError(f"Need {self.environmental_spop_path} in place to run these tests")
        self.written_file_path = None

    def tearDown(self) -> None:
        if self.written_file_path:
            os.unlink(self.written_file_path)

    def get_gen_pop(self):
        return SP.SerializedPopulation(self.generic_spop_path)

    def get_env_pop(self):
        return SP.SerializedPopulation(self.environmental_spop_path)

    def write_pop_file(self, population, filename):
        population.write(filename)
        self.written_file_path = filename

    # region pre-reqs
    def test_initial_states_of_spop_correct(self):
        gen_pop = self.get_gen_pop()
        gen_node_0 = gen_pop.nodes[0]
        pop_size = len(gen_node_0["individualHumans"])
        self.assertEqual(1000, pop_size)
        first_properties_gen = gen_node_0["individualHumans"][0]["Properties"]
        last_properties_gen = gen_node_0["individualHumans"][pop_size -1]["Properties"]
        self.assertEqual(len(first_properties_gen), 0)
        self.assertEqual(len(last_properties_gen), 0)

        env_pop = self.get_env_pop()
        env_pop_0 = env_pop.nodes[0]
        pop_size = len(env_pop_0["individualHumans"])
        self.assertEqual(1000, pop_size)

    def set_silly_property(self, original_population,
                           property_name, property_values):
        pop_node_0 = original_population.nodes[0]
        pop_size = len(pop_node_0["individualHumans"])
        for h in range(0, pop_size):
            specific_value = property_values[h%len(property_values)]
            pop_node_0["individualHumans"][h]["Properties"].append(f"{property_name}:{specific_value}")
        return original_population
    # endregion

    # region adding properties
    def verify_properties_addable(self, generated_population_name,
                                  property_values, property_name="Fruits"):
        generated_population = SP.SerializedPopulation(generated_population_name)
        first_node = generated_population.nodes[0]
        property_list = []
        for h in range(60, 60 + len(property_values)):
            property_list.append(first_node["individualHumans"][h]["Properties"])
            
        found_values = []
        for pl in property_list:
            self.assertEqual(len(pl), 1, msg=f"Should only be one property. Got {pl}")
            split_property = pl[0].split(":")
            self.assertEqual(split_property[0], property_name)
            found_values.append(pl[0].split(":")[1])
            
        self.assertEqual(sorted(found_values), sorted(property_values),
                         msg=f"Should get the same property values I set. Got {found_values}") 

    def test_add_properties_works_generic(self):
        # NOTE: dependent on test_initial_states_of_spop_correct
        gen_pop = self.get_gen_pop()
        silly_property = "Fruits"
        fruits = ["Apple", "Banana", "Coconut"]
        gen_pop = self.set_silly_property(original_population=gen_pop,
                                          property_name=silly_property,
                                          property_values=fruits)
        self.write_pop_file(gen_pop, "gen_pop_fruits.dtk")
        self.verify_properties_addable(generated_population_name="gen_pop_fruits.dtk",
                                       property_values=fruits,
                                       property_name=silly_property)

    def test_add_properties_works_environmental(self):
        # NOTE: dependent on test_initial_states_of_spop_correct
        env_pop = self.get_env_pop()
        silly_property = "Herbs"
        herbs = ["Thyme", "Sage", "Stempel", "Alpert"]
        env_pop = self.set_silly_property(original_population=env_pop,
                                          property_name=silly_property,
                                          property_values=herbs)
        self.write_pop_file(env_pop, "gen_pop_herbs.dtk")
        self.verify_properties_addable(generated_population_name="gen_pop_herbs.dtk",
                                       property_values=herbs,
                                       property_name=silly_property)
    # endregion

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/microstructure/test_change_ser_pop.py <==
import json
import unittest
import os
import hashlib

# Code under test
import emod_api.serialization.SerializedPopulation as SP
import hh_gen_toy as TOY
import add_hh_to_demo as ADD
import change_ser_pop as CSP

class ChangeSerializedPopulationTest(unittest.TestCase):
    def setUp(self) -> None:
        my_path = os.getcwd()
        self.generic_spop_path = os.path.join(my_path, "TestContent", "state-generic-00050.dtk")
        self.environmental_spop_path = os.path.join(my_path, "TestContent", "state-environmental-00050.dtk")
        if not os.path.isfile(self.generic_spop_path):
            raise FileNotFoundError(f"Need {self.generic_spop_path} in place to run these tests")
        if not os.path.isfile(self.environmental_spop_path):
            raise FileNotFoundError(f"Need {self.environmental_spop_path} in place to run these tests")
        self.written_file_path = None

    def tearDown(self) -> None:
        if self.written_file_path:
            os.unlink(self.written_file_path)

    def get_gen_pop(self):
        return SP.SerializedPopulation(self.generic_spop_path)

    def get_env_pop(self):
        return SP.SerializedPopulation(self.environmental_spop_path)

    def write_pop_file(self, population, filename):
        population.write(filename)
        self.written_file_path = filename

    # region pre-reqs
    def test_initial_states_of_spop_correct(self):
        gen_pop = self.get_gen_pop()
        gen_node_0 = gen_pop.nodes[0]
        pop_size = len(gen_node_0["individualHumans"])
        self.assertEqual(1000, pop_size)
        first_properties_gen = gen_node_0["individualHumans"][0]["Properties"]
        last_properties_gen = gen_node_0["individualHumans"][pop_size -1]["Properties"]
        self.assertEqual(len(first_properties_gen), 0)
        self.assertEqual(len(last_properties_gen), 0)

        env_pop = self.get_env_pop()
        env_pop_0 = env_pop.nodes[0]
        pop_size = len(env_pop_0["individualHumans"])
        self.assertEqual(1000, pop_size)

    def set_silly_property(self, original_population,
                           property_name, property_values):
        pop_node_0 = original_population.nodes[0]
        pop_size = len(pop_node_0["individualHumans"])
        for h in range(0, pop_size):
            specific_value = property_values[h%len(property_values)]
            pop_node_0["individualHumans"][h]["Properties"].append(f"{property_name}:{specific_value}")
        return original_population
    # endregion

    # region adding properties
    def verify_properties_addable(self, generated_population_name,
                                  property_values, property_name="Fruits"):
        generated_population = SP.SerializedPopulation(generated_population_name)
        first_node = generated_population.nodes[0]
        property_list = []
        for h in range(60, 60 + len(property_values)):
            property_list.append(first_node["individualHumans"][h]["Properties"])
            
        found_values = []
        for pl in property_list:
            self.assertEqual(len(pl), 1, msg=f"Should only be one property. Got {pl}")
            split_property = pl[0].split(":")
            self.assertEqual(split_property[0], property_name)
            found_values.append(pl[0].split(":")[1])
            
        self.assertEqual(sorted(found_values), sorted(property_values),
                         msg=f"Should get the same property values I set. Got {found_values}") 

    def test_add_properties_works_generic(self):
        # NOTE: dependent on test_initial_states_of_spop_correct
        gen_pop = self.get_gen_pop()
        silly_property = "Fruits"
        fruits = ["Apple", "Banana", "Coconut"]
        gen_pop = self.set_silly_property(original_population=gen_pop,
                                          property_name=silly_property,
                                          property_values=fruits)
        self.write_pop_file(gen_pop, "gen_pop_fruits.dtk")
        self.verify_properties_addable(generated_population_name="gen_pop_fruits.dtk",
                                       property_values=fruits,
                                       property_name=silly_property)

    def test_add_properties_works_environmental(self):
        # NOTE: dependent on test_initial_states_of_spop_correct
        env_pop = self.get_env_pop()
        silly_property = "Herbs"
        herbs = ["Thyme", "Sage", "Stempel", "Alpert"]
        env_pop = self.set_silly_property(original_population=env_pop,
                                          property_name=silly_property,
                                          property_values=herbs)
        self.write_pop_file(env_pop, "gen_pop_herbs.dtk")
        self.verify_properties_addable(generated_population_name="gen_pop_herbs.dtk",
                                       property_values=herbs,
                                       property_name=silly_property)
    # endregion
